@use "../utilities/convert";

.md-typeset {

  // Keyboard key
  .keys {

    // Define keyboard keys with left icon
    @each $name, $code in (
      // Extra Keys
      "power":         "\23FB",
      "fingerprint":   "\261D",
    ) {
      .key-#{$name}::before {
        padding-right: convert.px2em(6.4px);
        content: $code;
      }
    }

    // Define keyboard keys with right icon
    @each $name, $code in (
        // Extra Keys
    ) {
      .key-#{$name}::after {
        padding-left: convert.px2em(6.4px);
        content: $code;
      }
    }
  }
}
