@use "sass:color";

$drac-fg: hsl(60 30% 96.078%);
$drac-bg: hsl(231 15% 18%);
$drac-comment: hsl(225 27% 51%);
$drac-highlight: hsl(231 25% 25%) ;
$drac-selection: hsl(231 15% 30%);
$drac-blue: hsl(225 100% 75%);
$drac-cyan: hsl(191 97% 77%);
$drac-green: hsl(135 94% 65%);
$drac-orange: hsl(31 100% 71%);
$drac-pink: hsl(326 100% 74%);
$drac-purple: hsl(265 89% 78%);
$drac-red: hsl(0 100% 67%);
$drac-yellow: hsl(65 92% 76%);

$drac-grey: hsl(225 8% 51%);

// An approximation of the Alucard theme
$alucard-fg: #1F1F1F;
$alucard-bg: #F5F5F5;
$alucard-comment: #635D97;
$alucard-highlight: #DCDEEF;
$alucard-selection: #CFCFDE;
$alucard-blue: #3654c2;
$alucard-cyan: #036A96;
$alucard-green: #14720A;
$alucard-orange: #A34D14;
$alucard-pink: #A3134D;
$alucard-purple: #644AC9;
$alucard-red: #CB3A2A;
$alucard-yellow: #836E15;
