@use "palette/dracula";

/* Dark mode changes */
[data-md-color-scheme="slate"] {
  .md-typeset .task-list-control {
    .task-list-indicator::before {
    	background-color: var(--md-default-fg-color--lighter);
    }

    [type=checkbox]:checked + .task-list-indicator::before {
    	background-color: dracula.$drac-green;
    }
  }
}
