@use "palette/colors";

@use "general";

@use "extensions/admonition";
@use "extensions/arithmatex";
@use "extensions/critic";
@use "extensions/details";
@use "extensions/highlight";
@use "extensions/keys";
@use "extensions/magiclink";
@use "extensions/mark";
@use "extensions/progressbar";
@use "extensions/tabbed";
@use "extensions/tasklist";
@use "extensions/toc";
@use "extensions/superfences";
@use "extensions/steps";
@use "extensions/tables";

@use "material";
